@@ -26,13 +26,16 @@ class Remote(Runner):
         :param bool inline_env:
             Whether to 'inline' shell env vars as prefixed parameters, instead
             of trying to submit them via `.Channel.update_environment`.
-            Default:: ``False``.
+            Default: ``True``.
 
         .. versionchanged:: 2.3
             Added the ``inline_env`` parameter.
+        .. versionchanged:: 3.0
+            Changed the default value of ``inline_env`` from ``False`` to
+            ``True``.
         """
         self.inline_env = kwargs.pop("inline_env", None)
-        super(Remote, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def start(self, command, shell, env, timeout=None):
         self.channel = self.context.create_session()
@@ -69,7 +72,7 @@ class Remote(Runner):
 
     def run(self, command, **kwargs):
         kwargs.setdefault("replace_env", True)
-        return super(Remote, self).run(command, **kwargs)
+        return super().run(command, **kwargs)
 
     def read_proc_stdout(self, num_bytes):
         return self.channel.recv(num_bytes)
@@ -99,7 +102,7 @@ class Remote(Runner):
             # Submit hex ASCII character 3, aka ETX, which most Unix PTYs
             # interpret as a foreground SIGINT.
             # TODO: is there anything else we can do here to be more portable?
-            self.channel.send(u"\x03")
+            self.channel.send("\x03")
         else:
             raise interrupt
 
@@ -111,6 +114,7 @@ class Remote(Runner):
         return Result(**kwargs)
 
     def stop(self):
+        super()
         if hasattr(self, "channel"):
             self.channel.close()
 
@@ -168,7 +172,7 @@ class Result(InvokeResult):
 
     def __init__(self, **kwargs):
         connection = kwargs.pop("connection")
-        super(Result, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.connection = connection
 
     # TODO: have useful str/repr differentiation from invoke.Result,
