@@ -2,9 +2,9 @@
 This module contains helpers/fixtures to assist in testing Fabric-driven code.
 
 It is not intended for production use, and pulls in some test-oriented
-dependencies such as `mock <https://pypi.org/project/mock/>`_. You can install
-an 'extra' variant of Fabric to get these dependencies if you aren't already
-using them for your own testing purposes: ``pip install fabric[testing]``.
+dependencies as needed. You can install an 'extra' variant of Fabric to get
+these dependencies if you aren't already using them for your own testing
+purposes: ``pip install fabric[testing]``.
 
 .. note::
     If you're using pytest for your test suite, you may be interested in
@@ -19,20 +19,10 @@ from itertools import chain, repeat
 from io import BytesIO
 import os
 
-try:
-    from mock import Mock, PropertyMock, call, patch, ANY
-except ImportError:
-    import warnings
-
-    warning = (
-        "You appear to be missing some optional test-related dependencies;"
-        "please 'pip install fabric[testing]'."
-    )
-    warnings.warn(warning, ImportWarning)
-    raise
+from unittest.mock import Mock, PropertyMock, call, patch, ANY
 
 
-class Command(object):
+class Command:
     """
     Data record specifying params of a command execution to mock/expect.
 
@@ -67,6 +57,25 @@ class Command(object):
         # grow more dependencies? Ehhh
         return "<{} cmd={!r}>".format(self.__class__.__name__, self.cmd)
 
+    def expect_execution(self, channel):
+        """
+        Assert that the ``channel`` was used to run this command.
+
+        .. versionadded:: 2.7
+        """
+        channel.exec_command.assert_called_with(self.cmd or ANY)
+
+
+class ShellCommand(Command):
+    """
+    A pseudo-command that expects an interactive shell to be executed.
+
+    .. versionadded:: 2.7
+    """
+
+    def expect_execution(self, channel):
+        channel.invoke_shell.assert_called_once_with()
+
 
 class MockChannel(Mock):
     """
@@ -85,7 +94,7 @@ class MockChannel(Mock):
         object.__setattr__(self, "__stderr", kwargs.pop("stderr"))
         # Stdin less private so it can be asserted about
         object.__setattr__(self, "_stdin", BytesIO())
-        super(MockChannel, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def _get_child_mock(self, **kwargs):
         # Don't return our own class on sub-mocks.
@@ -101,7 +110,7 @@ class MockChannel(Mock):
         return object.__getattribute__(self, "_stdin").write(data)
 
 
-class Session(object):
+class Session:
     """
     A mock remote session of a single connection and 1 or more command execs.
 
@@ -254,8 +263,8 @@ class Session(object):
         for channel, command in zip(self.channels, self.commands):
             # Expect an open_session for each command exec
             session_opens.append(call())
-            # Expect that the channel gets an exec_command
-            channel.exec_command.assert_called_with(command.cmd or ANY)
+            # Expect that the channel gets an exec_command or etc
+            command.expect_execution(channel=channel)
             # Expect written stdin, if given
             if command.in_:
                 assert channel._stdin.getvalue() == command.in_
@@ -265,7 +274,7 @@ class Session(object):
         assert calls == session_opens
 
 
-class MockRemote(object):
+class MockRemote:
     """
     Class representing mocked remote state.
 
@@ -358,7 +367,7 @@ class MockRemote(object):
 
 # TODO: unify with the stuff in paramiko itself (now in its tests/conftest.py),
 # they're quite distinct and really shouldn't be.
-class MockSFTP(object):
+class MockSFTP:
     """
     Class managing mocked SFTP remote state.
 
@@ -376,27 +385,34 @@ class MockSFTP(object):
         # Set up mocks
         self.os_patcher = patch("fabric.transfer.os")
         self.client_patcher = patch("fabric.connection.SSHClient")
+        self.path_patcher = patch("fabric.transfer.Path")
         mock_os = self.os_patcher.start()
         Client = self.client_patcher.start()
+        self.path_patcher.start()
         sftp = Client.return_value.open_sftp.return_value
 
         # Handle common filepath massage actions; tests will assume these.
         def fake_abspath(path):
-            return "/local/{}".format(path)
+            # Run normpath to avoid tests not seeing abspath wrinkles (like
+            # trailing slash chomping)
+            return "/local/{}".format(os.path.normpath(path))
 
         mock_os.path.abspath.side_effect = fake_abspath
         sftp.getcwd.return_value = "/remote"
-        # Ensure stat st_mode is a real number; Python 2 stat.S_IMODE doesn't
-        # appear to care if it's handed a MagicMock, but Python 3's does (?!)
+        # Ensure stat st_mode is a real number; Python 3's stat.S_IMODE doesn't
+        # like just being handed a MagicMock?
         fake_mode = 0o644  # arbitrary real-ish mode
         sftp.stat.return_value.st_mode = fake_mode
         mock_os.stat.return_value.st_mode = fake_mode
         # Not super clear to me why the 'wraps' functionality in mock isn't
-        # working for this :(
-        mock_os.path.basename.side_effect = os.path.basename
+        # working for this :( reinstate a bunch of os(.path) so it still works
+        mock_os.sep = os.sep
+        for name in ("basename", "split", "join", "normpath"):
+            getattr(mock_os.path, name).side_effect = getattr(os.path, name)
         # Return the sftp and OS mocks for use by decorator use case.
         return sftp, mock_os
 
     def stop(self):
         self.os_patcher.stop()
         self.client_patcher.stop()
+        self.path_patcher.stop()
